@@ -6,7 +6,7 @@ use Mojo::UserAgent;
 use Carp 'croak';
 use strict;
 
-our $VERSION = '1.54';
+our $VERSION = '1.55';
 
 has providers => sub {
   return {
@@ -107,7 +107,7 @@ sub _get_token {
 
   # No error or code response from provider callback URL
   unless ($c->param('code')) {
-    $c->redirect_to($self->_get_authorize_url($c, $args));
+    $c->redirect_to($self->_get_authorize_url($c, $args)) if $args->{redirect} // 1;
     return $p ? $p->resolve(undef) : undef;
   }
 
@@ -442,6 +442,10 @@ C<%args> can have:
 Useful if your provider uses different hosts for accessing different accounts.
 The default is specified in the provider configuration.
 
+=item * redirect
+
+Set C<redirect> to 0 to disable automatic redirect.
+
 =item * scope
 
 Scope to ask for credentials to. Should be a space separated list.
